{
  lib,
  rustPlatform,
  nix-gitignore,
  bash,
  makeWrapper,
  dav1d,
  vulkan-loader,
  libGL,
  wayland,
  pkg-config,
  libxkbcommon,
  pkgs,
}: let
  version = (builtins.fromTOML (builtins.readFile ./engine/Cargo.toml)).package.version;
  src = nix-gitignore.gitignoreSource [] ./.;
in
  rustPlatform.buildRustPackage rec {
    pname = "zenyx";
    inherit src version;
    cargoLock.lockFile = ./Cargo.lock;
    nativeBuildInputs = [
      makeWrapper
      pkg-config
    ];
    buildInputs = with pkgs; [
      wayland
      vulkan-loader
      libxkbcommon
      libGL
      libxkbcommon
      xorg.libXcursor
      xorg.libXrandr
      xorg.libXi
      xorg.libX11
      xorg.libxcb
      bash
      dav1d
    ];
    doCheck = false;
    LD_LIBRARY_PATH = "${pkgs.lib.makeLibraryPath buildInputs}";

    fixupPhase = ''
      wrapProgram $out/bin/${pname} --set PATH ${bash}/bin:\$PATH --set LD_LIBRARY_PATH ${pkgs.lib.makeLibraryPath buildInputs}
    '';

    meta = {
      description = "Test";
      license = lib.licenses.mit;
      platforms = lib.platforms.linux;
      mainProgram = "zenyx";
    };
  }
